Documentation
¶
Index ¶
- Constants
- type AllRequestTypesExample
- func (m *AllRequestTypesExample) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *AllRequestTypesExample) MarshalBinary() ([]byte, error)
- func (m *AllRequestTypesExample) UnmarshalBinary(b []byte) error
- func (m *AllRequestTypesExample) Validate(formats strfmt.Registry) error
- type AllResponseTypesExample
- func (m *AllResponseTypesExample) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *AllResponseTypesExample) MarshalBinary() ([]byte, error)
- func (m *AllResponseTypesExample) UnmarshalBinary(b []byte) error
- func (m *AllResponseTypesExample) Validate(formats strfmt.Registry) error
- type AuthenticationMessage
- func (m *AuthenticationMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *AuthenticationMessage) ID() int32
- func (m *AuthenticationMessage) MarshalBinary() ([]byte, error)
- func (m AuthenticationMessage) MarshalJSON() ([]byte, error)
- func (m *AuthenticationMessage) Op() string
- func (m *AuthenticationMessage) SetID(val int32)
- func (m *AuthenticationMessage) SetOp(val string)
- func (m *AuthenticationMessage) UnmarshalBinary(b []byte) error
- func (m *AuthenticationMessage) UnmarshalJSON(raw []byte) error
- func (m *AuthenticationMessage) Validate(formats strfmt.Registry) error
- type ConnectionMessage
- func (m *ConnectionMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *ConnectionMessage) ID() int32
- func (m *ConnectionMessage) MarshalBinary() ([]byte, error)
- func (m ConnectionMessage) MarshalJSON() ([]byte, error)
- func (m *ConnectionMessage) Op() string
- func (m *ConnectionMessage) SetID(val int32)
- func (m *ConnectionMessage) SetOp(val string)
- func (m *ConnectionMessage) UnmarshalBinary(b []byte) error
- func (m *ConnectionMessage) UnmarshalJSON(raw []byte) error
- func (m *ConnectionMessage) Validate(formats strfmt.Registry) error
- type HeartbeatMessage
- func (m *HeartbeatMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *HeartbeatMessage) ID() int32
- func (m *HeartbeatMessage) MarshalBinary() ([]byte, error)
- func (m HeartbeatMessage) MarshalJSON() ([]byte, error)
- func (m *HeartbeatMessage) Op() string
- func (m *HeartbeatMessage) SetID(val int32)
- func (m *HeartbeatMessage) SetOp(val string)
- func (m *HeartbeatMessage) UnmarshalBinary(b []byte) error
- func (m *HeartbeatMessage) UnmarshalJSON(raw []byte) error
- func (m *HeartbeatMessage) Validate(formats strfmt.Registry) error
- type HeartbeatMessageAllOf1
- type KeyLineDefinition
- type KeyLineSelection
- type MarketChange
- type MarketChangeMessage
- func (m *MarketChangeMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *MarketChangeMessage) ID() int32
- func (m *MarketChangeMessage) MarshalBinary() ([]byte, error)
- func (m MarketChangeMessage) MarshalJSON() ([]byte, error)
- func (m *MarketChangeMessage) Op() string
- func (m *MarketChangeMessage) SetID(val int32)
- func (m *MarketChangeMessage) SetOp(val string)
- func (m *MarketChangeMessage) UnmarshalBinary(b []byte) error
- func (m *MarketChangeMessage) UnmarshalJSON(raw []byte) error
- func (m *MarketChangeMessage) Validate(formats strfmt.Registry) error
- type MarketDataFilter
- type MarketDefinition
- type MarketFilter
- type MarketSubscriptionMessage
- func (m *MarketSubscriptionMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *MarketSubscriptionMessage) ID() int32
- func (m *MarketSubscriptionMessage) MarshalBinary() ([]byte, error)
- func (m MarketSubscriptionMessage) MarshalJSON() ([]byte, error)
- func (m *MarketSubscriptionMessage) Op() string
- func (m *MarketSubscriptionMessage) SetID(val int32)
- func (m *MarketSubscriptionMessage) SetOp(val string)
- func (m *MarketSubscriptionMessage) UnmarshalBinary(b []byte) error
- func (m *MarketSubscriptionMessage) UnmarshalJSON(raw []byte) error
- func (m *MarketSubscriptionMessage) Validate(formats strfmt.Registry) error
- type Order
- type OrderChangeMessage
- func (m *OrderChangeMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *OrderChangeMessage) ID() int32
- func (m *OrderChangeMessage) MarshalBinary() ([]byte, error)
- func (m OrderChangeMessage) MarshalJSON() ([]byte, error)
- func (m *OrderChangeMessage) Op() string
- func (m *OrderChangeMessage) SetID(val int32)
- func (m *OrderChangeMessage) SetOp(val string)
- func (m *OrderChangeMessage) UnmarshalBinary(b []byte) error
- func (m *OrderChangeMessage) UnmarshalJSON(raw []byte) error
- func (m *OrderChangeMessage) Validate(formats strfmt.Registry) error
- type OrderFilter
- type OrderMarketChange
- type OrderRunnerChange
- type OrderSubscriptionMessage
- func (m *OrderSubscriptionMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *OrderSubscriptionMessage) ID() int32
- func (m *OrderSubscriptionMessage) MarshalBinary() ([]byte, error)
- func (m OrderSubscriptionMessage) MarshalJSON() ([]byte, error)
- func (m *OrderSubscriptionMessage) Op() string
- func (m *OrderSubscriptionMessage) SetID(val int32)
- func (m *OrderSubscriptionMessage) SetOp(val string)
- func (m *OrderSubscriptionMessage) UnmarshalBinary(b []byte) error
- func (m *OrderSubscriptionMessage) UnmarshalJSON(raw []byte) error
- func (m *OrderSubscriptionMessage) Validate(formats strfmt.Registry) error
- type PriceLadderDefinition
- type RequestMessage
- type ResponseMessage
- type RunnerChange
- type RunnerDefinition
- type StatusMessage
- func (m *StatusMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (m *StatusMessage) ID() int32
- func (m *StatusMessage) MarshalBinary() ([]byte, error)
- func (m StatusMessage) MarshalJSON() ([]byte, error)
- func (m *StatusMessage) Op() string
- func (m *StatusMessage) SetID(val int32)
- func (m *StatusMessage) SetOp(val string)
- func (m *StatusMessage) UnmarshalBinary(b []byte) error
- func (m *StatusMessage) UnmarshalJSON(raw []byte) error
- func (m *StatusMessage) Validate(formats strfmt.Registry) error
- type StrategyMatchChange
Constants ¶
const ( // AllRequestTypesExampleOpTypesHeartbeat captures enum value "heartbeat" AllRequestTypesExampleOpTypesHeartbeat string = "heartbeat" // AllRequestTypesExampleOpTypesAuthentication captures enum value "authentication" AllRequestTypesExampleOpTypesAuthentication string = "authentication" // AllRequestTypesExampleOpTypesMarketSubscription captures enum value "marketSubscription" AllRequestTypesExampleOpTypesMarketSubscription string = "marketSubscription" // AllRequestTypesExampleOpTypesOrderSubscription captures enum value "orderSubscription" AllRequestTypesExampleOpTypesOrderSubscription string = "orderSubscription" )
const ( // AllResponseTypesExampleOpTypesConnection captures enum value "connection" AllResponseTypesExampleOpTypesConnection string = "connection" // AllResponseTypesExampleOpTypesStatus captures enum value "status" AllResponseTypesExampleOpTypesStatus string = "status" // AllResponseTypesExampleOpTypesMcm captures enum value "mcm" AllResponseTypesExampleOpTypesMcm string = "mcm" // AllResponseTypesExampleOpTypesOcm captures enum value "ocm" AllResponseTypesExampleOpTypesOcm string = "ocm" )
const ( // MarketDefinitionBettingTypeODDS captures enum value "ODDS" MarketDefinitionBettingTypeODDS string = "ODDS" // MarketDefinitionBettingTypeLINE captures enum value "LINE" MarketDefinitionBettingTypeLINE string = "LINE" // MarketDefinitionBettingTypeRANGE captures enum value "RANGE" MarketDefinitionBettingTypeRANGE string = "RANGE" // MarketDefinitionBettingTypeASIANHANDICAPDOUBLELINE captures enum value "ASIAN_HANDICAP_DOUBLE_LINE" MarketDefinitionBettingTypeASIANHANDICAPDOUBLELINE string = "ASIAN_HANDICAP_DOUBLE_LINE" // MarketDefinitionBettingTypeASIANHANDICAPSINGLELINE captures enum value "ASIAN_HANDICAP_SINGLE_LINE" MarketDefinitionBettingTypeASIANHANDICAPSINGLELINE string = "ASIAN_HANDICAP_SINGLE_LINE" )
const ( // MarketDefinitionStatusINACTIVE captures enum value "INACTIVE" MarketDefinitionStatusINACTIVE string = "INACTIVE" // MarketDefinitionStatusOPEN captures enum value "OPEN" MarketDefinitionStatusOPEN string = "OPEN" // MarketDefinitionStatusSUSPENDED captures enum value "SUSPENDED" MarketDefinitionStatusSUSPENDED string = "SUSPENDED" // MarketDefinitionStatusCLOSED captures enum value "CLOSED" MarketDefinitionStatusCLOSED string = "CLOSED" )
const ( // OrderOtL captures enum value "L" OrderOtL string = "L" // OrderOtLOC captures enum value "LOC" OrderOtLOC string = "LOC" // OrderOtMOC captures enum value "MOC" OrderOtMOC string = "MOC" )
const ( // OrderPtL captures enum value "L" OrderPtL string = "L" // OrderPtP captures enum value "P" OrderPtP string = "P" // OrderPtMOC captures enum value "MOC" OrderPtMOC string = "MOC" )
const ( // OrderSideB captures enum value "B" OrderSideB string = "B" // OrderSideL captures enum value "L" OrderSideL string = "L" )
const ( // OrderStatusE captures enum value "E" OrderStatusE string = "E" // OrderStatusEC captures enum value "EC" OrderStatusEC string = "EC" )
const ( // PriceLadderDefinitionTypeCLASSIC captures enum value "CLASSIC" PriceLadderDefinitionTypeCLASSIC string = "CLASSIC" // PriceLadderDefinitionTypeFINEST captures enum value "FINEST" PriceLadderDefinitionTypeFINEST string = "FINEST" // PriceLadderDefinitionTypeLINERANGE captures enum value "LINE_RANGE" PriceLadderDefinitionTypeLINERANGE string = "LINE_RANGE" )
const ( // RunnerDefinitionStatusACTIVE captures enum value "ACTIVE" RunnerDefinitionStatusACTIVE string = "ACTIVE" // RunnerDefinitionStatusWINNER captures enum value "WINNER" RunnerDefinitionStatusWINNER string = "WINNER" // RunnerDefinitionStatusLOSER captures enum value "LOSER" RunnerDefinitionStatusLOSER string = "LOSER" // RunnerDefinitionStatusREMOVED captures enum value "REMOVED" RunnerDefinitionStatusREMOVED string = "REMOVED" // RunnerDefinitionStatusREMOVEDVACANT captures enum value "REMOVED_VACANT" RunnerDefinitionStatusREMOVEDVACANT string = "REMOVED_VACANT" // RunnerDefinitionStatusHIDDEN captures enum value "HIDDEN" RunnerDefinitionStatusHIDDEN string = "HIDDEN" // RunnerDefinitionStatusPLACED captures enum value "PLACED" RunnerDefinitionStatusPLACED string = "PLACED" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AllRequestTypesExample ¶
type AllRequestTypesExample struct {
// authentication
Authentication *AuthenticationMessage `json:"authentication,omitempty"`
// heartbeat
Heartbeat *HeartbeatMessage `json:"heartbeat,omitempty"`
// market subscription
MarketSubscription *MarketSubscriptionMessage `json:"marketSubscription,omitempty"`
// op types
// Enum: [heartbeat authentication marketSubscription orderSubscription]
OpTypes string `json:"opTypes,omitempty"`
// order subscription message
OrderSubscriptionMessage *OrderSubscriptionMessage `json:"orderSubscriptionMessage,omitempty"`
}
AllRequestTypesExample all request types example
swagger:model AllRequestTypesExample
func (*AllRequestTypesExample) ContextValidate ¶
func (m *AllRequestTypesExample) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validate this all request types example based on the context it is used
func (*AllRequestTypesExample) MarshalBinary ¶
func (m *AllRequestTypesExample) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*AllRequestTypesExample) UnmarshalBinary ¶
func (m *AllRequestTypesExample) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type AllResponseTypesExample ¶
type AllResponseTypesExample struct {
// connection
Connection *ConnectionMessage `json:"connection,omitempty"`
// market change message
MarketChangeMessage *MarketChangeMessage `json:"marketChangeMessage,omitempty"`
// op types
// Enum: [connection status mcm ocm]
OpTypes string `json:"opTypes,omitempty"`
// order change message
OrderChangeMessage *OrderChangeMessage `json:"orderChangeMessage,omitempty"`
// status
Status *StatusMessage `json:"status,omitempty"`
}
AllResponseTypesExample all response types example
swagger:model AllResponseTypesExample
func (*AllResponseTypesExample) ContextValidate ¶
func (m *AllResponseTypesExample) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validate this all response types example based on the context it is used
func (*AllResponseTypesExample) MarshalBinary ¶
func (m *AllResponseTypesExample) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*AllResponseTypesExample) UnmarshalBinary ¶
func (m *AllResponseTypesExample) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type AuthenticationMessage ¶
type AuthenticationMessage struct {
// app key
AppKey string `json:"appKey,omitempty"`
// session
Session string `json:"session,omitempty"`
// contains filtered or unexported fields
}
AuthenticationMessage authentication message
swagger:model AuthenticationMessage
func (*AuthenticationMessage) ContextValidate ¶
ContextValidate validate this authentication message based on the context it is used
func (*AuthenticationMessage) ID ¶
func (m *AuthenticationMessage) ID() int32
ID gets the id of this subtype
func (*AuthenticationMessage) MarshalBinary ¶
func (m *AuthenticationMessage) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (AuthenticationMessage) MarshalJSON ¶
func (m AuthenticationMessage) MarshalJSON() ([]byte, error)
MarshalJSON marshals this object with a polymorphic type to a JSON structure
func (*AuthenticationMessage) Op ¶
func (m *AuthenticationMessage) Op() string
Op gets the op of this subtype
func (*AuthenticationMessage) SetID ¶
func (m *AuthenticationMessage) SetID(val int32)
SetID sets the id of this subtype
func (*AuthenticationMessage) SetOp ¶
func (m *AuthenticationMessage) SetOp(val string)
SetOp sets the op of this subtype
func (*AuthenticationMessage) UnmarshalBinary ¶
func (m *AuthenticationMessage) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
func (*AuthenticationMessage) UnmarshalJSON ¶
func (m *AuthenticationMessage) UnmarshalJSON(raw []byte) error
UnmarshalJSON unmarshals this object with a polymorphic type from a JSON structure
type ConnectionMessage ¶
type ConnectionMessage struct {
// The connection id
ConnectionID string `json:"connectionId,omitempty"`
// contains filtered or unexported fields
}
ConnectionMessage connection message
swagger:model ConnectionMessage
func (*ConnectionMessage) ContextValidate ¶
ContextValidate validate this connection message based on the context it is used
func (*ConnectionMessage) ID ¶
func (m *ConnectionMessage) ID() int32
ID gets the id of this subtype
func (*ConnectionMessage) MarshalBinary ¶
func (m *ConnectionMessage) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (ConnectionMessage) MarshalJSON ¶
func (m ConnectionMessage) MarshalJSON() ([]byte, error)
MarshalJSON marshals this object with a polymorphic type to a JSON structure
func (*ConnectionMessage) Op ¶
func (m *ConnectionMessage) Op() string
Op gets the op of this subtype
func (*ConnectionMessage) SetID ¶
func (m *ConnectionMessage) SetID(val int32)
SetID sets the id of this subtype
func (*ConnectionMessage) SetOp ¶
func (m *ConnectionMessage) SetOp(val string)
SetOp sets the op of this subtype
func (*ConnectionMessage) UnmarshalBinary ¶
func (m *ConnectionMessage) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
func (*ConnectionMessage) UnmarshalJSON ¶
func (m *ConnectionMessage) UnmarshalJSON(raw []byte) error
UnmarshalJSON unmarshals this object with a polymorphic type from a JSON structure
type HeartbeatMessage ¶
type HeartbeatMessage struct {
HeartbeatMessageAllOf1
// contains filtered or unexported fields
}
HeartbeatMessage heartbeat message
swagger:model HeartbeatMessage
func (*HeartbeatMessage) ContextValidate ¶
ContextValidate validate this heartbeat message based on the context it is used
func (*HeartbeatMessage) MarshalBinary ¶
func (m *HeartbeatMessage) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (HeartbeatMessage) MarshalJSON ¶
func (m HeartbeatMessage) MarshalJSON() ([]byte, error)
MarshalJSON marshals this object with a polymorphic type to a JSON structure
func (*HeartbeatMessage) SetID ¶
func (m *HeartbeatMessage) SetID(val int32)
SetID sets the id of this subtype
func (*HeartbeatMessage) SetOp ¶
func (m *HeartbeatMessage) SetOp(val string)
SetOp sets the op of this subtype
func (*HeartbeatMessage) UnmarshalBinary ¶
func (m *HeartbeatMessage) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
func (*HeartbeatMessage) UnmarshalJSON ¶
func (m *HeartbeatMessage) UnmarshalJSON(raw []byte) error
UnmarshalJSON unmarshals this object with a polymorphic type from a JSON structure
type HeartbeatMessageAllOf1 ¶
type HeartbeatMessageAllOf1 interface{}
HeartbeatMessageAllOf1 heartbeat message all of1
swagger:model HeartbeatMessageAllOf1
type KeyLineDefinition ¶
type KeyLineDefinition struct {
// kl
Kl []*KeyLineSelection `json:"kl"`
}
KeyLineDefinition key line definition
swagger:model KeyLineDefinition
func (*KeyLineDefinition) ContextValidate ¶
ContextValidate validate this key line definition based on the context it is used
func (*KeyLineDefinition) MarshalBinary ¶
func (m *KeyLineDefinition) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*KeyLineDefinition) UnmarshalBinary ¶
func (m *KeyLineDefinition) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type KeyLineSelection ¶
type KeyLineSelection struct {
// hc
Hc float64 `json:"hc,omitempty"`
// id
ID int64 `json:"id,omitempty"`
}
KeyLineSelection key line selection
swagger:model KeyLineSelection
func (*KeyLineSelection) ContextValidate ¶
ContextValidate validates this key line selection based on context it is used
func (*KeyLineSelection) MarshalBinary ¶
func (m *KeyLineSelection) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*KeyLineSelection) UnmarshalBinary ¶
func (m *KeyLineSelection) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type MarketChange ¶
type MarketChange struct {
// Conflated - have more than a single change been combined (or null if not conflated)
Con bool `json:"con,omitempty"`
// Market Id - the id of the market
ID string `json:"id,omitempty"`
// Image - replace existing prices / data with the data supplied: it is not a delta (or null if delta)
Img bool `json:"img,omitempty"`
// Market Definition - the definition of the market (or null if un-changed)
MarketDefinition *MarketDefinition `json:"marketDefinition,omitempty"`
// Runner Changes - a list of changes to runners (or null if un-changed)
Rc []*RunnerChange `json:"rc"`
// The total amount matched across the market. This value is truncated at 2dp (or null if un-changed)
Tv float64 `json:"tv,omitempty"`
}
MarketChange market change
swagger:model MarketChange
func (*MarketChange) ContextValidate ¶
ContextValidate validate this market change based on the context it is used
func (*MarketChange) MarshalBinary ¶
func (m *MarketChange) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*MarketChange) UnmarshalBinary ¶
func (m *MarketChange) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type MarketChangeMessage ¶
type MarketChangeMessage struct {
// Token value (non-null) should be stored and passed in a MarketSubscriptionMessage to resume subscription (in case of disconnect)
Clk string `json:"clk,omitempty"`
// Conflate Milliseconds - the conflation rate (may differ from that requested if subscription is delayed)
ConflateMs int64 `json:"conflateMs,omitempty"`
// Change Type - set to indicate the type of change - if null this is a delta)
// Enum: [SUB_IMAGE RESUB_DELTA HEARTBEAT]
Ct string `json:"ct,omitempty"`
// Heartbeat Milliseconds - the heartbeat rate (may differ from requested: bounds are 500 to 30000)
HeartbeatMs int64 `json:"heartbeatMs,omitempty"`
// Token value (non-null) should be stored and passed in a MarketSubscriptionMessage to resume subscription (in case of disconnect)
InitialClk string `json:"initialClk,omitempty"`
// MarketChanges - the modifications to markets (will be null on a heartbeat
Mc []*MarketChange `json:"mc"`
// Publish Time (in millis since epoch) that the changes were generated
Pt int64 `json:"pt,omitempty"`
// Segment Type - if the change is split into multiple segments, this denotes the beginning and end of a change, and segments in between. Will be null if data is not segmented
// Enum: [SEG_START SEG SEG_END]
SegmentType string `json:"segmentType,omitempty"`
// Stream status: set to null if the exchange stream data is up to date and 503 if the downstream services are experiencing latencies
Status int32 `json:"status,omitempty"`
// contains filtered or unexported fields
}
MarketChangeMessage market change message
swagger:model MarketChangeMessage
func (*MarketChangeMessage) ContextValidate ¶
ContextValidate validate this market change message based on the context it is used
func (*MarketChangeMessage) ID ¶
func (m *MarketChangeMessage) ID() int32
ID gets the id of this subtype
func (*MarketChangeMessage) MarshalBinary ¶
func (m *MarketChangeMessage) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (MarketChangeMessage) MarshalJSON ¶
func (m MarketChangeMessage) MarshalJSON() ([]byte, error)
MarshalJSON marshals this object with a polymorphic type to a JSON structure
func (*MarketChangeMessage) Op ¶
func (m *MarketChangeMessage) Op() string
Op gets the op of this subtype
func (*MarketChangeMessage) SetID ¶
func (m *MarketChangeMessage) SetID(val int32)
SetID sets the id of this subtype
func (*MarketChangeMessage) SetOp ¶
func (m *MarketChangeMessage) SetOp(val string)
SetOp sets the op of this subtype
func (*MarketChangeMessage) UnmarshalBinary ¶
func (m *MarketChangeMessage) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
func (*MarketChangeMessage) UnmarshalJSON ¶
func (m *MarketChangeMessage) UnmarshalJSON(raw []byte) error
UnmarshalJSON unmarshals this object with a polymorphic type from a JSON structure
type MarketDataFilter ¶
type MarketDataFilter struct {
// fields
Fields []string `json:"fields"`
// ladder levels
LadderLevels int32 `json:"ladderLevels,omitempty"`
}
MarketDataFilter market data filter
swagger:model MarketDataFilter
func (*MarketDataFilter) ContextValidate ¶
ContextValidate validates this market data filter based on context it is used
func (*MarketDataFilter) MarshalBinary ¶
func (m *MarketDataFilter) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*MarketDataFilter) UnmarshalBinary ¶
func (m *MarketDataFilter) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type MarketDefinition ¶
type MarketDefinition struct {
// bet delay
BetDelay int32 `json:"betDelay,omitempty"`
// betting type
// Enum: [ODDS LINE RANGE ASIAN_HANDICAP_DOUBLE_LINE ASIAN_HANDICAP_SINGLE_LINE]
BettingType string `json:"bettingType,omitempty"`
// bsp market
BspMarket bool `json:"bspMarket,omitempty"`
// bsp reconciled
BspReconciled bool `json:"bspReconciled,omitempty"`
// complete
Complete bool `json:"complete,omitempty"`
// country code
CountryCode string `json:"countryCode,omitempty"`
// cross matching
CrossMatching bool `json:"crossMatching,omitempty"`
// discount allowed
DiscountAllowed bool `json:"discountAllowed,omitempty"`
// each way divisor
EachWayDivisor float64 `json:"eachWayDivisor,omitempty"`
// event Id
EventID string `json:"eventId,omitempty"`
// The Event Type the market is contained within.
EventTypeID string `json:"eventTypeId,omitempty"`
// in play
InPlay bool `json:"inPlay,omitempty"`
// Definition of a markets key line selection (for valid markets), comprising the selectionId and handicap of the team it is applied to.
KeyLineDefinition *KeyLineDefinition `json:"keyLineDefinition,omitempty"`
// For Handicap and Line markets, the lines available on this market will be between the range of lineMinUnit and lineMaxUnit, in increments of the lineInterval value. e.g. If unit is runs, lineMinUnit=10, lineMaxUnit=20 and lineInterval=0.5, then valid lines include 10, 10.5, 11, 11.5 up to 20 runs.
LineInterval float64 `json:"lineInterval,omitempty"`
// For Handicap and Line markets, the maximum value for the outcome, in market units for this market (eg 100 runs).
LineMaxUnit float64 `json:"lineMaxUnit,omitempty"`
// For Handicap and Line markets, the minimum value for the outcome, in market units for this market (eg 0 runs).
LineMinUnit float64 `json:"lineMinUnit,omitempty"`
// market base rate
MarketBaseRate float64 `json:"marketBaseRate,omitempty"`
// market time
// Format: date-time
MarketTime strfmt.DateTime `json:"marketTime,omitempty"`
// market type
MarketType string `json:"marketType,omitempty"`
// number of active runners
NumberOfActiveRunners int32 `json:"numberOfActiveRunners,omitempty"`
// number of winners
NumberOfWinners int32 `json:"numberOfWinners,omitempty"`
// open date
// Format: date-time
OpenDate strfmt.DateTime `json:"openDate,omitempty"`
// persistence enabled
PersistenceEnabled bool `json:"persistenceEnabled,omitempty"`
// Definition of the price ladder type and any related data.
PriceLadderDefinition *PriceLadderDefinition `json:"priceLadderDefinition,omitempty"`
// race type
RaceType string `json:"raceType,omitempty"`
// The market regulators.
Regulators []string `json:"regulators"`
// runners
Runners []*RunnerDefinition `json:"runners"`
// runners voidable
RunnersVoidable bool `json:"runnersVoidable,omitempty"`
// settled time
// Format: date-time
SettledTime strfmt.DateTime `json:"settledTime,omitempty"`
// status
// Enum: [INACTIVE OPEN SUSPENDED CLOSED]
Status string `json:"status,omitempty"`
// suspend time
// Format: date-time
SuspendTime strfmt.DateTime `json:"suspendTime,omitempty"`
// timezone
Timezone string `json:"timezone,omitempty"`
// turn in play enabled
TurnInPlayEnabled bool `json:"turnInPlayEnabled,omitempty"`
// venue
Venue string `json:"venue,omitempty"`
// version
Version int64 `json:"version,omitempty"`
}
MarketDefinition market definition
swagger:model MarketDefinition
func (*MarketDefinition) ContextValidate ¶
ContextValidate validate this market definition based on the context it is used
func (*MarketDefinition) MarshalBinary ¶
func (m *MarketDefinition) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*MarketDefinition) UnmarshalBinary ¶
func (m *MarketDefinition) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type MarketFilter ¶
type MarketFilter struct {
// betting types
BettingTypes []string `json:"bettingTypes"`
// bsp market
BspMarket bool `json:"bspMarket,omitempty"`
// country codes
CountryCodes []string `json:"countryCodes"`
// event ids
EventIds []string `json:"eventIds"`
// event type ids
EventTypeIds []string `json:"eventTypeIds"`
// market ids
MarketIds []string `json:"marketIds"`
// market types
MarketTypes []string `json:"marketTypes"`
// race types
RaceTypes []string `json:"raceTypes"`
// turn in play enabled
TurnInPlayEnabled bool `json:"turnInPlayEnabled,omitempty"`
// venues
Venues []string `json:"venues"`
}
MarketFilter market filter
swagger:model MarketFilter
func (*MarketFilter) ContextValidate ¶
ContextValidate validates this market filter based on context it is used
func (*MarketFilter) MarshalBinary ¶
func (m *MarketFilter) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*MarketFilter) UnmarshalBinary ¶
func (m *MarketFilter) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type MarketSubscriptionMessage ¶
type MarketSubscriptionMessage struct {
// Token value delta (received in MarketChangeMessage) that should be passed to resume a subscription
Clk string `json:"clk,omitempty"`
// Conflate Milliseconds - the conflation rate (looped back on initial image after validation: bounds are 0 to 120000)
ConflateMs int64 `json:"conflateMs,omitempty"`
// Heartbeat Milliseconds - the heartbeat rate (looped back on initial image after validation: bounds are 500 to 5000)
HeartbeatMs int64 `json:"heartbeatMs,omitempty"`
// Token value (received in initial MarketChangeMessage) that should be passed to resume a subscription
InitialClk string `json:"initialClk,omitempty"`
// market data filter
MarketDataFilter *MarketDataFilter `json:"marketDataFilter,omitempty"`
// market filter
MarketFilter *MarketFilter `json:"marketFilter,omitempty"`
// Segmentation Enabled - allow the server to send large sets of data in segments, instead of a single block
SegmentationEnabled bool `json:"segmentationEnabled,omitempty"`
// contains filtered or unexported fields
}
MarketSubscriptionMessage market subscription message
swagger:model MarketSubscriptionMessage
func (*MarketSubscriptionMessage) ContextValidate ¶
func (m *MarketSubscriptionMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validate this market subscription message based on the context it is used
func (*MarketSubscriptionMessage) ID ¶
func (m *MarketSubscriptionMessage) ID() int32
ID gets the id of this subtype
func (*MarketSubscriptionMessage) MarshalBinary ¶
func (m *MarketSubscriptionMessage) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (MarketSubscriptionMessage) MarshalJSON ¶
func (m MarketSubscriptionMessage) MarshalJSON() ([]byte, error)
MarshalJSON marshals this object with a polymorphic type to a JSON structure
func (*MarketSubscriptionMessage) Op ¶
func (m *MarketSubscriptionMessage) Op() string
Op gets the op of this subtype
func (*MarketSubscriptionMessage) SetID ¶
func (m *MarketSubscriptionMessage) SetID(val int32)
SetID sets the id of this subtype
func (*MarketSubscriptionMessage) SetOp ¶
func (m *MarketSubscriptionMessage) SetOp(val string)
SetOp sets the op of this subtype
func (*MarketSubscriptionMessage) UnmarshalBinary ¶
func (m *MarketSubscriptionMessage) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
func (*MarketSubscriptionMessage) UnmarshalJSON ¶
func (m *MarketSubscriptionMessage) UnmarshalJSON(raw []byte) error
UnmarshalJSON unmarshals this object with a polymorphic type from a JSON structure
type Order ¶
type Order struct {
// Average Price Matched - the average price the order was matched at (null if the order is not matched). This value is not meaningful for activity on Line markets and is not guaranteed to be returned or maintained for these markets.
Avp float64 `json:"avp,omitempty"`
// BSP Liability - the BSP liability of the order (null if the order is not a BSP order)
Bsp float64 `json:"bsp,omitempty"`
// Cancelled Date - the date the order was cancelled (null if the order is not cancelled)
Cd int64 `json:"cd,omitempty"`
// Bet Id - the id of the order
ID string `json:"id,omitempty"`
// Lapsed Date - the date the order was lapsed (null if the order is not lapsed)
Ld int64 `json:"ld,omitempty"`
// Lapse Status Reason Code - the reason that some or all of this order has been lapsed (null if no portion of the order is lapsed
Lsrc string `json:"lsrc,omitempty"`
// Matched Date - the date the order was matched (null if the order is not matched)
Md int64 `json:"md,omitempty"`
// Order Type - the type of the order (L = LIMIT, MOC = MARKET_ON_CLOSE, LOC = LIMIT_ON_CLOSE)
// Enum: [L LOC MOC]
Ot string `json:"ot,omitempty"`
// Price - the original placed price of the order. Line markets operate at even-money odds of 2.0. However, price for these markets refers to the line positions available as defined by the markets min-max range and interval steps
P float64 `json:"p,omitempty"`
// Placed Date - the date the order was placed
Pd int64 `json:"pd,omitempty"`
// Persistence Type - whether the order will persist at in play or not (L = LAPSE, P = PERSIST, MOC = Market On Close)
// Enum: [L P MOC]
Pt string `json:"pt,omitempty"`
// Regulator Auth Code - the auth code returned by the regulator
Rac string `json:"rac,omitempty"`
// Regulator Code - the regulator of the order
Rc string `json:"rc,omitempty"`
// Order Reference - the customer's order reference for this order (empty string if one was not set)
Rfo string `json:"rfo,omitempty"`
// Strategy Reference - the customer's strategy reference for this order (empty string if one was not set)
Rfs string `json:"rfs,omitempty"`
// Size - the original placed size of the order
S float64 `json:"s,omitempty"`
// Size Cancelled - the amount of the order that has been cancelled
Sc float64 `json:"sc,omitempty"`
// Side - the side of the order. For Line markets a 'B' bet refers to a SELL line and an 'L' bet refers to a BUY line.
// Enum: [B L]
Side string `json:"side,omitempty"`
// Size Lapsed - the amount of the order that has been lapsed
Sl float64 `json:"sl,omitempty"`
// Size Matched - the amount of the order that has been matched
Sm float64 `json:"sm,omitempty"`
// Size Remaining - the amount of the order that is remaining unmatched
Sr float64 `json:"sr,omitempty"`
// Status - the status of the order (E = EXECUTABLE, EC = EXECUTION_COMPLETE)
// Enum: [E EC]
Status string `json:"status,omitempty"`
// Size Voided - the amount of the order that has been voided
Sv float64 `json:"sv,omitempty"`
}
Order order
swagger:model Order
func (*Order) ContextValidate ¶
ContextValidate validates this order based on context it is used
func (*Order) MarshalBinary ¶
MarshalBinary interface implementation
func (*Order) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type OrderChangeMessage ¶
type OrderChangeMessage struct {
// Token value (non-null) should be stored and passed in a MarketSubscriptionMessage to resume subscription (in case of disconnect)
Clk string `json:"clk,omitempty"`
// Conflate Milliseconds - the conflation rate (may differ from that requested if subscription is delayed)
ConflateMs int64 `json:"conflateMs,omitempty"`
// Change Type - set to indicate the type of change - if null this is a delta)
// Enum: [SUB_IMAGE RESUB_DELTA HEARTBEAT]
Ct string `json:"ct,omitempty"`
// Heartbeat Milliseconds - the heartbeat rate (may differ from requested: bounds are 500 to 30000)
HeartbeatMs int64 `json:"heartbeatMs,omitempty"`
// Token value (non-null) should be stored and passed in a MarketSubscriptionMessage to resume subscription (in case of disconnect)
InitialClk string `json:"initialClk,omitempty"`
// OrderMarketChanges - the modifications to account's orders (will be null on a heartbeat
Oc []*OrderMarketChange `json:"oc"`
// Publish Time (in millis since epoch) that the changes were generated
Pt int64 `json:"pt,omitempty"`
// Segment Type - if the change is split into multiple segments, this denotes the beginning and end of a change, and segments in between. Will be null if data is not segmented
// Enum: [SEG_START SEG SEG_END]
SegmentType string `json:"segmentType,omitempty"`
// Stream status: set to null if the exchange stream data is up to date and 503 if the downstream services are experiencing latencies
Status int32 `json:"status,omitempty"`
// contains filtered or unexported fields
}
OrderChangeMessage order change message
swagger:model OrderChangeMessage
func (*OrderChangeMessage) ContextValidate ¶
ContextValidate validate this order change message based on the context it is used
func (*OrderChangeMessage) ID ¶
func (m *OrderChangeMessage) ID() int32
ID gets the id of this subtype
func (*OrderChangeMessage) MarshalBinary ¶
func (m *OrderChangeMessage) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (OrderChangeMessage) MarshalJSON ¶
func (m OrderChangeMessage) MarshalJSON() ([]byte, error)
MarshalJSON marshals this object with a polymorphic type to a JSON structure
func (*OrderChangeMessage) Op ¶
func (m *OrderChangeMessage) Op() string
Op gets the op of this subtype
func (*OrderChangeMessage) SetID ¶
func (m *OrderChangeMessage) SetID(val int32)
SetID sets the id of this subtype
func (*OrderChangeMessage) SetOp ¶
func (m *OrderChangeMessage) SetOp(val string)
SetOp sets the op of this subtype
func (*OrderChangeMessage) UnmarshalBinary ¶
func (m *OrderChangeMessage) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
func (*OrderChangeMessage) UnmarshalJSON ¶
func (m *OrderChangeMessage) UnmarshalJSON(raw []byte) error
UnmarshalJSON unmarshals this object with a polymorphic type from a JSON structure
type OrderFilter ¶
type OrderFilter struct {
// Internal use only & should not be set on your filter (your subscription is already locked to your account). If set subscription will fail.
AccountIds []int64 `json:"accountIds"`
// Restricts to specified customerStrategyRefs; this will filter orders and StrategyMatchChanges accordingly (Note: overall postition is not filtered)
CustomerStrategyRefs []string `json:"customerStrategyRefs"`
// Returns overall / net position (See: OrderRunnerChange.mb / OrderRunnerChange.ml). Default=true
IncludeOverallPosition bool `json:"includeOverallPosition,omitempty"`
// Returns strategy positions (See: OrderRunnerChange.smc=Map<customerStrategyRef, StrategyMatchChange>) - these are sent in delta format as per overall position. Default=false
PartitionMatchedByStrategyRef bool `json:"partitionMatchedByStrategyRef,omitempty"`
}
OrderFilter order filter
swagger:model OrderFilter
func (*OrderFilter) ContextValidate ¶
ContextValidate validates this order filter based on context it is used
func (*OrderFilter) MarshalBinary ¶
func (m *OrderFilter) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*OrderFilter) UnmarshalBinary ¶
func (m *OrderFilter) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type OrderMarketChange ¶
type OrderMarketChange struct {
// account Id
AccountID int64 `json:"accountId,omitempty"`
// closed
Closed bool `json:"closed,omitempty"`
// full image
FullImage bool `json:"fullImage,omitempty"`
// Market Id - the id of the market the order is on
ID string `json:"id,omitempty"`
// Order Changes - a list of changes to orders on a selection
Orc []*OrderRunnerChange `json:"orc"`
}
OrderMarketChange order market change
swagger:model OrderMarketChange
func (*OrderMarketChange) ContextValidate ¶
ContextValidate validate this order market change based on the context it is used
func (*OrderMarketChange) MarshalBinary ¶
func (m *OrderMarketChange) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*OrderMarketChange) UnmarshalBinary ¶
func (m *OrderMarketChange) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type OrderRunnerChange ¶
type OrderRunnerChange struct {
// full image
FullImage bool `json:"fullImage,omitempty"`
// Handicap - the handicap of the runner (selection) (null if not applicable)
Hc float64 `json:"hc,omitempty"`
// Selection Id - the id of the runner (selection)
ID int64 `json:"id,omitempty"`
// Matched Backs - matched amounts by distinct matched price on the Back side for this runner (selection)
Mb [][]float64 `json:"mb"`
// Matched Lays - matched amounts by distinct matched price on the Lay side for this runner (selection)
Ml [][]float64 `json:"ml"`
// Strategy Matches - Matched Backs and Matched Lays grouped by strategy reference
Smc map[string]StrategyMatchChange `json:"smc,omitempty"`
// Unmatched Orders - orders on this runner (selection) that are not fully matched
Uo []*Order `json:"uo"`
}
OrderRunnerChange order runner change
swagger:model OrderRunnerChange
func (*OrderRunnerChange) ContextValidate ¶
ContextValidate validate this order runner change based on the context it is used
func (*OrderRunnerChange) MarshalBinary ¶
func (m *OrderRunnerChange) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*OrderRunnerChange) UnmarshalBinary ¶
func (m *OrderRunnerChange) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type OrderSubscriptionMessage ¶
type OrderSubscriptionMessage struct {
// Token value delta (received in MarketChangeMessage) that should be passed to resume a subscription
Clk string `json:"clk,omitempty"`
// Conflate Milliseconds - the conflation rate (looped back on initial image after validation: bounds are 0 to 120000)
ConflateMs int64 `json:"conflateMs,omitempty"`
// Heartbeat Milliseconds - the heartbeat rate (looped back on initial image after validation: bounds are 500 to 5000)
HeartbeatMs int64 `json:"heartbeatMs,omitempty"`
// Token value (received in initial MarketChangeMessage) that should be passed to resume a subscription
InitialClk string `json:"initialClk,omitempty"`
// Optional filter applied to order subscription
OrderFilter *OrderFilter `json:"orderFilter,omitempty"`
// Segmentation Enabled - allow the server to send large sets of data in segments, instead of a single block
SegmentationEnabled bool `json:"segmentationEnabled,omitempty"`
// contains filtered or unexported fields
}
OrderSubscriptionMessage order subscription message
swagger:model OrderSubscriptionMessage
func (*OrderSubscriptionMessage) ContextValidate ¶
func (m *OrderSubscriptionMessage) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validate this order subscription message based on the context it is used
func (*OrderSubscriptionMessage) ID ¶
func (m *OrderSubscriptionMessage) ID() int32
ID gets the id of this subtype
func (*OrderSubscriptionMessage) MarshalBinary ¶
func (m *OrderSubscriptionMessage) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (OrderSubscriptionMessage) MarshalJSON ¶
func (m OrderSubscriptionMessage) MarshalJSON() ([]byte, error)
MarshalJSON marshals this object with a polymorphic type to a JSON structure
func (*OrderSubscriptionMessage) Op ¶
func (m *OrderSubscriptionMessage) Op() string
Op gets the op of this subtype
func (*OrderSubscriptionMessage) SetID ¶
func (m *OrderSubscriptionMessage) SetID(val int32)
SetID sets the id of this subtype
func (*OrderSubscriptionMessage) SetOp ¶
func (m *OrderSubscriptionMessage) SetOp(val string)
SetOp sets the op of this subtype
func (*OrderSubscriptionMessage) UnmarshalBinary ¶
func (m *OrderSubscriptionMessage) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
func (*OrderSubscriptionMessage) UnmarshalJSON ¶
func (m *OrderSubscriptionMessage) UnmarshalJSON(raw []byte) error
UnmarshalJSON unmarshals this object with a polymorphic type from a JSON structure
type PriceLadderDefinition ¶
type PriceLadderDefinition struct {
// type
// Enum: [CLASSIC FINEST LINE_RANGE]
Type string `json:"type,omitempty"`
}
PriceLadderDefinition price ladder definition
swagger:model PriceLadderDefinition
func (*PriceLadderDefinition) ContextValidate ¶
ContextValidate validates this price ladder definition based on context it is used
func (*PriceLadderDefinition) MarshalBinary ¶
func (m *PriceLadderDefinition) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*PriceLadderDefinition) UnmarshalBinary ¶
func (m *PriceLadderDefinition) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RequestMessage ¶
type RequestMessage interface {
runtime.Validatable
runtime.ContextValidatable
// Client generated unique id to link request with response (like json rpc)
ID() int32
SetID(int32)
// The operation type
Op() string
SetOp(string)
}
RequestMessage request message
swagger:discriminator RequestMessage op
func UnmarshalRequestMessage ¶
UnmarshalRequestMessage unmarshals polymorphic RequestMessage
func UnmarshalRequestMessageSlice ¶
func UnmarshalRequestMessageSlice(reader io.Reader, consumer runtime.Consumer) ([]RequestMessage, error)
UnmarshalRequestMessageSlice unmarshals polymorphic slices of RequestMessage
type ResponseMessage ¶
type ResponseMessage interface {
runtime.Validatable
runtime.ContextValidatable
// Client generated unique id to link request with response (like json rpc)
ID() int32
SetID(int32)
// The operation type
Op() string
SetOp(string)
}
ResponseMessage response message
swagger:discriminator ResponseMessage op
func UnmarshalResponseMessage ¶
UnmarshalResponseMessage unmarshals polymorphic ResponseMessage
func UnmarshalResponseMessageSlice ¶
func UnmarshalResponseMessageSlice(reader io.Reader, consumer runtime.Consumer) ([]ResponseMessage, error)
UnmarshalResponseMessageSlice unmarshals polymorphic slices of ResponseMessage
type RunnerChange ¶
type RunnerChange struct {
// Available To Back - PriceVol tuple delta of price changes (0 vol is remove)
Atb [][]float64 `json:"atb"`
// Available To Lay - PriceVol tuple delta of price changes (0 vol is remove)
Atl [][]float64 `json:"atl"`
// Best Available To Back - LevelPriceVol triple delta of price changes, keyed by level (0 vol is remove)
Batb [][]float64 `json:"batb"`
// Best Available To Lay - LevelPriceVol triple delta of price changes, keyed by level (0 vol is remove)
Batl [][]float64 `json:"batl"`
// Best Display Available To Back (includes virtual prices)- LevelPriceVol triple delta of price changes, keyed by level (0 vol is remove)
Bdatb [][]float64 `json:"bdatb"`
// Best Display Available To Lay (includes virtual prices)- LevelPriceVol triple delta of price changes, keyed by level (0 vol is remove)
Bdatl [][]float64 `json:"bdatl"`
// Handicap - the handicap of the runner (selection) (null if not applicable)
Hc float64 `json:"hc,omitempty"`
// Selection Id - the id of the runner (selection)
ID int64 `json:"id,omitempty"`
// Last Traded Price - The last traded price (or null if un-changed)
Ltp float64 `json:"ltp,omitempty"`
// Starting Price Back - PriceVol tuple delta of price changes (0 vol is remove)
Spb [][]float64 `json:"spb"`
// Starting Price Far - The far starting price (or null if un-changed)
Spf float64 `json:"spf,omitempty"`
// Starting Price Lay - PriceVol tuple delta of price changes (0 vol is remove)
Spl [][]float64 `json:"spl"`
// Starting Price Near - The far starting price (or null if un-changed)
Spn float64 `json:"spn,omitempty"`
// Traded - PriceVol tuple delta of price changes (0 vol is remove)
Trd [][]float64 `json:"trd"`
// The total amount matched. This value is truncated at 2dp.
Tv float64 `json:"tv,omitempty"`
}
RunnerChange runner change
swagger:model RunnerChange
func (*RunnerChange) ContextValidate ¶
ContextValidate validates this runner change based on context it is used
func (*RunnerChange) MarshalBinary ¶
func (m *RunnerChange) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RunnerChange) UnmarshalBinary ¶
func (m *RunnerChange) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RunnerDefinition ¶
type RunnerDefinition struct {
// adjustment factor
AdjustmentFactor float64 `json:"adjustmentFactor,omitempty"`
// bsp
Bsp float64 `json:"bsp,omitempty"`
// Handicap - the handicap of the runner (selection) (null if not applicable)
Hc float64 `json:"hc,omitempty"`
// Selection Id - the id of the runner (selection)
ID int64 `json:"id,omitempty"`
// removal date
// Format: date-time
RemovalDate strfmt.DateTime `json:"removalDate,omitempty"`
// sort priority
SortPriority int32 `json:"sortPriority,omitempty"`
// status
// Enum: [ACTIVE WINNER LOSER REMOVED REMOVED_VACANT HIDDEN PLACED]
Status string `json:"status,omitempty"`
}
RunnerDefinition runner definition
swagger:model RunnerDefinition
func (*RunnerDefinition) ContextValidate ¶
ContextValidate validates this runner definition based on context it is used
func (*RunnerDefinition) MarshalBinary ¶
func (m *RunnerDefinition) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RunnerDefinition) UnmarshalBinary ¶
func (m *RunnerDefinition) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type StatusMessage ¶
type StatusMessage struct {
// Is the connection now closed
ConnectionClosed bool `json:"connectionClosed,omitempty"`
// The connection id
ConnectionID string `json:"connectionId,omitempty"`
// The number of connections available for this account at this moment in time. Present on responses to Authentication messages only.
ConnectionsAvailable int32 `json:"connectionsAvailable,omitempty"`
// The type of error in case of a failure
// Enum: [NO_APP_KEY INVALID_APP_KEY NO_SESSION INVALID_SESSION_INFORMATION NOT_AUTHORIZED INVALID_INPUT INVALID_CLOCK UNEXPECTED_ERROR TIMEOUT SUBSCRIPTION_LIMIT_EXCEEDED INVALID_REQUEST CONNECTION_FAILED MAX_CONNECTION_LIMIT_EXCEEDED TOO_MANY_REQUESTS]
ErrorCode string `json:"errorCode,omitempty"`
// Additional message in case of a failure
ErrorMessage string `json:"errorMessage,omitempty"`
// The status of the last request
// Enum: [SUCCESS FAILURE]
StatusCode string `json:"statusCode,omitempty"`
// contains filtered or unexported fields
}
StatusMessage status message
swagger:model StatusMessage
func (*StatusMessage) ContextValidate ¶
ContextValidate validate this status message based on the context it is used
func (*StatusMessage) MarshalBinary ¶
func (m *StatusMessage) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (StatusMessage) MarshalJSON ¶
func (m StatusMessage) MarshalJSON() ([]byte, error)
MarshalJSON marshals this object with a polymorphic type to a JSON structure
func (*StatusMessage) SetID ¶
func (m *StatusMessage) SetID(val int32)
SetID sets the id of this subtype
func (*StatusMessage) SetOp ¶
func (m *StatusMessage) SetOp(val string)
SetOp sets the op of this subtype
func (*StatusMessage) UnmarshalBinary ¶
func (m *StatusMessage) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
func (*StatusMessage) UnmarshalJSON ¶
func (m *StatusMessage) UnmarshalJSON(raw []byte) error
UnmarshalJSON unmarshals this object with a polymorphic type from a JSON structure
type StrategyMatchChange ¶
type StrategyMatchChange struct {
// Matched Backs - matched amounts by distinct matched price on the Back side for this strategy
Mb [][]float64 `json:"mb"`
// Matched Lays - matched amounts by distinct matched price on the Lay side for this strategy
Ml [][]float64 `json:"ml"`
}
StrategyMatchChange strategy match change
swagger:model StrategyMatchChange
func (*StrategyMatchChange) ContextValidate ¶
ContextValidate validates this strategy match change based on context it is used
func (*StrategyMatchChange) MarshalBinary ¶
func (m *StrategyMatchChange) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*StrategyMatchChange) UnmarshalBinary ¶
func (m *StrategyMatchChange) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
Source Files
¶
- all_request_types_example.go
- all_response_types_example.go
- authentication_message.go
- connection_message.go
- heartbeat_message.go
- key_line_definition.go
- key_line_selection.go
- market_change.go
- market_change_message.go
- market_data_filter.go
- market_definition.go
- market_filter.go
- market_subscription_message.go
- order.go
- order_change_message.go
- order_filter.go
- order_market_change.go
- order_runner_change.go
- order_subscription_message.go
- price_ladder_definition.go
- request_message.go
- response_message.go
- runner_change.go
- runner_definition.go
- status_message.go
- strategy_match_change.go